Package: mosaicCalc
Type: Package
Title: R-Language Based Calculus Operations for Teaching
Description: Software to support the introductory *MOSAIC Calculus* 
    textbook <https://www.mosaic-web.org/MOSAIC-Calculus/>),
    one of many data- and modeling-oriented educational resources developed by 
    Project MOSAIC (<https://www.mosaic-web.org/>). Provides symbolic and
    numerical differentiation and integration, as well as support for 
    applied linear algebra (for data science), and differential equations/dynamics.
    Includes grammar-of-graphics-based functions for drawing vector fields, trajectories, etc.
    The software is suitable for general use, but intended mainly for teaching calculus.
Version: 0.6.4
Depends: R (>= 3.5.0)
Imports: calculus, Deriv, dplyr, ggformula, ggplot2, glue, grDevices,
        MASS, Matrix, metR (>= 0.11.0), mosaicCore (>= 0.9.2), mosaic,
        orthopolynom, rlang, Ryacas, sp, stats, tibble
Suggests: testthat, knitr, palmerpenguins, rmarkdown, cubature, plotly,
        mosaicData
Author: Daniel T. Kaplan <kaplan@macalester.edu>, Randall Pruim <rpruim@calvin.edu>, Nicholas J. Horton <nhorton@amherst.edu>
Maintainer: Daniel Kaplan <kaplan@macalester.edu>
VignetteBuilder: knitr
NeedsCompilation: no
License: GPL (>= 2)
LazyLoad: true
LazyData: true
URL: https://github.com/ProjectMOSAIC/mosaicCalc
BugReports: https://github.com/ProjectMOSAIC/mosaicCalc/issues
RoxygenNote: 7.2.1
Encoding: UTF-8
Packaged: 2024-07-26 15:30:22 UTC; kaplan
Repository: CRAN
Date/Publication: 2024-07-26 15:50:02 UTC
Built: R 4.6.0; ; 2026-04-25 14:02:09 UTC; unix
