# Generated by roxygen2: do not edit by hand

S3method(D,default)
S3method(D,formula)
S3method(makeFun,numeric)
export("%dot%")
export("%onto%")
export("%perp%")
export(D)
export(Integrate)
export(Iterate)
export(PE_fun1)
export(PE_fun2)
export(Picket)
export(Zeros)
export(antiD)
export(argM)
export(as_magnitude)
export(bind_params)
export(bounds)
export(box_set)
export(connector)
export(contour_plot)
export(df2matrix)
export(domain)
export(equality_constraint)
export(flow_field)
export(fourier_M)
export(fourier_set)
export(gradient_plot)
export(inequality_constraint)
export(inscribed_circle)
export(integrateODE)
export(interactive_plot)
export(is_in_domain)
export(legendre_M)
export(legendre_set)
export(makeODE)
export(normalize)
export(ns_M)
export(ns_set)
export(numD)
export(qspliner)
export(slice_plot)
export(spliner)
export(streamlines)
export(surface_plot)
export(surface_with_contours)
export(symbolicD)
export(traj_plot)
export(traj_plot_3D)
export(trajectory_euler)
export(vectorfield_plot)
importFrom(Deriv,Deriv)
importFrom(MASS,fractions)
importFrom(Matrix,norm)
importFrom(Ryacas,as_r)
importFrom(Ryacas,yac)
importFrom(calculus,integral)
importFrom(dplyr,bind_rows)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guides)
importFrom(ggplot2,scale_color_viridis_c)
importFrom(ggplot2,scale_fill_viridis_c)
importFrom(glue,glue)
importFrom(grDevices,extendrange)
importFrom(metR,geom_contour2)
importFrom(metR,geom_contour_fill)
importFrom(metR,geom_text_contour)
importFrom(mosaic,connector)
importFrom(mosaic,expandFun)
importFrom(mosaic,fitModel)
importFrom(mosaic,inferArgs)
importFrom(mosaic,spliner)
importFrom(mosaicCore,makeFun)
importFrom(orthopolynom,legendre.polynomials)
importFrom(sp,point.in.polygon)
importFrom(stats,approxfun)
importFrom(stats,as.formula)
importFrom(stats,integrate)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,optim)
importFrom(stats,optimize)
importFrom(stats,quantile)
importFrom(stats,runif)
importFrom(stats,uniroot)
importFrom(tibble,tibble)
importFrom(tibble,tribble)
importFrom(utils,capture.output)
